/* hardware definitions for LCD display */
#define LPT1     0x378         /* lpt1 I/O port base address */
#define LPT2     0x278         /* lpt2 I/O port base address */
#define LPT3     0x3BC         /* lpt3 I/O port base address */

/* Display D0-D7 comes from the data port via inverters 74LS14 */
#define LCD_DATA LPT3          /* LCD connected to lpt1 (Pin 2..9) */
#define DATA_MASK  0x0ff       /* xor mask for inverted bits at data port */

/* control lines goes through 74LS14 inverters too */
#define LCD_CTRL LCD_DATA+2    /* control port address */
#define STRB 1                 /* Pin 1, inverted LPT bit */
#define AFED 2                 /* Pin14, inverted LPT bit */
#define INIT 4                 /* Pin16 */
#define SEL  8                 /* Pin17, inverted LPT bit */
#define CTRL_MASK 0x00         /* xor mask for ctrl lines */
#define LCD_EN   STRB          /* enable connected to STROBE Pin */
#define LCD_RS   AFED          /* command / data  connected to AUTOFEED */
#define LCD_BL   SEL           /* backlight intensity  connected to SELECT */

#define MIN_DLY    1           /* minimum delay in us */
#define DEF_DLY   40           /* default delay for command execution */
#define MAX_DLY 1640           /* long delay for clear screen and cursor home */

/* Display size */
#define LCD_LINES 4            /* number of display lines */
#define LCD_ROWS   4           /* number of display lines */
#define LCD_COLS  20           /* number of display columns */

/* No user servicable parts below this line! */

/* Drop an error line if no appropriate hardware was found */
#ifndef LCD_DATA
#error LCD_DATA undefined, read hardware.h!
#endif
